Struct google_dfareporting3::DateRange [−][src]
pub struct DateRange {
pub start_date: Option<String>,
pub kind: Option<String>,
pub end_date: Option<String>,
pub relative_date_range: Option<String>,
}Represents a date range.
This type is not used in any activity, and only used as part of another schema.
Fields
start_date: Option<String>
The start date of the date range, inclusive. A string of the format: "yyyy-MM-dd".
kind: Option<String>
The kind of resource this is, in this case dfareporting#dateRange.
end_date: Option<String>
The end date of the date range, inclusive. A string of the format: "yyyy-MM-dd".
relative_date_range: Option<String>
The date range relative to the date of when the report is run.