Struct google_dfareporting3::FileUrls [−][src]
The URLs where the completed report file can be downloaded.
This type is not used in any activity, and only used as part of another schema.
Fields
browser_url: Option<String>
The URL for downloading the report data through a browser.
api_url: Option<String>
The URL for downloading the report data through the API.