Struct google_dfareporting3::OperatingSystemsListResponse [−][src]
pub struct OperatingSystemsListResponse {
pub kind: Option<String>,
pub operating_systems: Option<Vec<OperatingSystem>>,
}Operating System List Response
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list operating systems (response)
Fields
kind: Option<String>
Identifies what kind of resource this is. Value: the fixed string "dfareporting#operatingSystemsListResponse".
operating_systems: Option<Vec<OperatingSystem>>
Operating system collection.