Struct google_dfareporting3::PostalCode [−][src]
pub struct PostalCode {
pub code: Option<String>,
pub kind: Option<String>,
pub country_dart_id: Option<String>,
pub id: Option<String>,
pub country_code: Option<String>,
}Contains information about a postal code that can be targeted by ads.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- get postal codes (response)
- list postal codes (none)
Fields
code: Option<String>
Postal code. This is equivalent to the id field.
kind: Option<String>
Identifies what kind of resource this is. Value: the fixed string "dfareporting#postalCode".
country_dart_id: Option<String>
DART ID of the country to which this postal code belongs.
id: Option<String>
ID of this postal code.
country_code: Option<String>
Country code of the country to which this postal code belongs.