Struct google_dfareporting3::PostalCodesListResponse [−][src]
pub struct PostalCodesListResponse {
pub kind: Option<String>,
pub postal_codes: Option<Vec<PostalCode>>,
}Postal Code List Response
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- list postal codes (response)
Fields
kind: Option<String>
Identifies what kind of resource this is. Value: the fixed string "dfareporting#postalCodesListResponse".
postal_codes: Option<Vec<PostalCode>>
Postal code collection.