Struct google_dfareporting3::Recipient [−][src]
pub struct Recipient {
pub kind: Option<String>,
pub delivery_type: Option<String>,
pub email: Option<String>,
}Represents a recipient.
This type is not used in any activity, and only used as part of another schema.
Fields
kind: Option<String>
The kind of resource this is, in this case dfareporting#recipient.
delivery_type: Option<String>
The delivery type for the recipient.
email: Option<String>
The email address of the recipient.