Struct google_dfareporting3::ReportCompatibleFields [−][src]
pub struct ReportCompatibleFields {
pub metrics: Option<Vec<Metric>>,
pub kind: Option<String>,
pub pivoted_activity_metrics: Option<Vec<Metric>>,
pub dimensions: Option<Vec<Dimension>>,
pub dimension_filters: Option<Vec<Dimension>>,
}Represents fields that are compatible to be selected for a report of type "STANDARD".
This type is not used in any activity, and only used as part of another schema.
Fields
metrics: Option<Vec<Metric>>
Metrics which are compatible to be selected in the "metricNames" section of the report.
kind: Option<String>
The kind of resource this is, in this case dfareporting#reportCompatibleFields.
pivoted_activity_metrics: Option<Vec<Metric>>
Metrics which are compatible to be selected as activity metrics to pivot on in the "activities" section of the report.
dimensions: Option<Vec<Dimension>>
Dimensions which are compatible to be selected in the "dimensions" section of the report.
dimension_filters: Option<Vec<Dimension>>
Dimensions which are compatible to be selected in the "dimensionFilters" section of the report.