Struct google_dfareporting3::ReportDelivery [−][src]
pub struct ReportDelivery {
pub message: Option<String>,
pub email_owner_delivery_type: Option<String>,
pub recipients: Option<Vec<Recipient>>,
pub email_owner: Option<bool>,
}The report's email delivery settings.
This type is not used in any activity, and only used as part of another schema.
Fields
message: Option<String>
The message to be sent with each email.
email_owner_delivery_type: Option<String>
The type of delivery for the owner to receive, if enabled.
recipients: Option<Vec<Recipient>>
The list of recipients to which to email the report.
email_owner: Option<bool>
Whether the report should be emailed to the report owner.