Struct google_dfareporting3::SortedDimension [−][src]
pub struct SortedDimension {
pub kind: Option<String>,
pub name: Option<String>,
pub sort_order: Option<String>,
}Represents a sorted dimension.
This type is not used in any activity, and only used as part of another schema.
Fields
kind: Option<String>
The kind of resource this is, in this case dfareporting#sortedDimension.
name: Option<String>
The name of the dimension.
sort_order: Option<String>
An optional sort order for the dimension column.